@@ -237,8 +237,8 @@ class Trimesh(Geometry3D):
         # we can keep face and vertex normals in the cache without recomputing
         # if faces or vertices have been removed, normals are validated before
         # being returned so there is no danger of inconsistent dimensions
-        self._cache.clear(exclude=['face_normals',
-                                   'vertex_normals'])
+        self._cache.clear(exclude={'face_normals',
+                                   'vertex_normals'})
         self.metadata['processed'] = True
         return self
 
@@ -302,12 +302,12 @@ class Trimesh(Geometry3D):
           Indexes of self.vertices
         """
         if values is None or len(values) == 0:
-            if 'faces' in self._data:
-                del self._data['faces']
-            return
-        values = np.asanyarray(values, dtype=np.int64)
+            return self._data.data.pop('faces', None)
+        if not (isinstance(values, np.ndarray) and values.dtype == np.int64):
+            values = np.asanyarray(values, dtype=np.int64)
+
         # automatically triangulate quad faces
-        if util.is_shape(values, (-1, 4)):
+        if len(values.shape) == 2 and values.shape[1] == 4:
             log.info('triangulating quad faces')
             values = geometry.triangulate_quads(values)
         self._data['faces'] = values
@@ -1091,20 +1091,19 @@ class Trimesh(Geometry3D):
 
     def merge_vertices(self, **kwargs):
         """
-        If a mesh has vertices that are closer than
-        trimesh.constants.tol.merge reindex faces to reference
-        the same index for both vertices.
+        Removes duplicate vertices, grouped by position and
+        optionally texture coordinate and normal.
 
         Parameters
         -------------
         mesh : Trimesh object
           Mesh to merge vertices on
-        use_tex : bool
-          If True for textured meshes merge vertices
-          with identical positions AND UV coordinates.
-        use_norm : bool
-          If True meshes with vertex normals defined will
-          only have vertices merged with identical normal
+        merge_tex : bool
+          If True textured meshes with UV coordinates will
+          have vertices merged regardless of UV coordinates
+        merge_norm : bool
+          If True, meshes with vertex normals will have
+          vertices merged ignoring different normals
         digits_vertex : None or int
           Number of digits to consider for vertex position
         digits_norm : int
@@ -1826,7 +1825,7 @@ class Trimesh(Geometry3D):
                              n_samples=1,
                              threshold=0.0):
         """
-        Computes stable orientations of a mesh and their quasi-static probabilites.
+        Computes stable orientations of a mesh and their quasi-static probabilities.
 
         This method samples the location of the center of mass from a multivariate
         gaussian (mean at com, cov equal to identity times sigma) over n_samples.
@@ -2032,10 +2031,10 @@ class Trimesh(Geometry3D):
 
         Parameters
         ------------
-        plane_normal: (3) vector for plane normal
-          Normal vector of section plane
         plane_origin : (3, ) float
           Point on the cross section plane
+        plane_normal: (3) vector for plane normal
+          Normal vector of section plane
         heights : (n, ) float
           Each section is offset by height along
           the plane normal.
@@ -2236,19 +2235,17 @@ class Trimesh(Geometry3D):
                 matrix)[0]
 
         # preserve face normals if we have them stored
-        new_face_normals = None
         if has_rotation and 'face_normals' in self._cache:
             # transform face normals by rotation component
-            new_face_normals = util.unitize(
+            self._cache.cache['face_normals'] = util.unitize(
                 transformations.transform_points(
                     self.face_normals,
                     matrix=matrix,
                     translate=False))
 
         # preserve vertex normals if we have them stored
-        new_vertex_normals = None
         if has_rotation and 'vertex_normals' in self._cache:
-            new_vertex_normals = util.unitize(
+            self._cache.cache['vertex_normals'] = util.unitize(
                 transformations.transform_points(
                     self.vertex_normals,
                     matrix=matrix,
@@ -2265,15 +2262,12 @@ class Trimesh(Geometry3D):
 
         # assign the new values
         self.vertices = new_vertices
-        # may be None if we didn't have them previously
-        self.face_normals = new_face_normals
-        self.vertex_normals = new_vertex_normals
 
         # preserve normals and topology in cache
         # while dumping everything else
-        self._cache.clear(exclude=[
+        self._cache.clear(exclude={
             'face_normals',   # transformed by us
-            'vertex_normals'  # also transformed by us
+            'vertex_normals',  # also transformed by us
             'face_adjacency',  # topological
             'face_adjacency_edges',
             'face_adjacency_unshared',
@@ -2286,10 +2280,9 @@ class Trimesh(Geometry3D):
             'edges_sparse',
             'body_count',
             'faces_unique_edges',
-            'euler_number', ])
+            'euler_number'})
         # set the cache ID with the current hash value
         self._cache.id_set()
-
         log.debug('mesh transformed by matrix')
         return self
 
